# About 

This is Japana. a Japanese analysis tool using Jim Breen's JMdict & KanjiDic2
You need to provide a text: novel, short story, song lyrics, article, sentence ..etc. 
The program will return a word list ordered by frequency. 
each dictionary in the list has at least the word and the number of occurrence (frequency)
an depending on configurations: pronunciation and meaning

# Requirements

all requirements all stored in `requirements.txt`. In addition, you need to install [Jamdict](https://github.com/neocl/jamdict)



# Other Projects

This project has been made into:
* CLI application: [Japana-CLI](https://github.com/reem-codes/japana-cli)
* Web app: [Japana](http://japana.reem-codes.com)


